﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BaseDataGrid
{
    public class ViewModel
    {
        public ObservableCollection<GridData> Data { get; set; }
        private int NoLevels = 7;
        public ViewModel()
        {
            CreateData();

        }

        private string[] names = { "John", "Kim", "Sandy", "Mark", "Josh", "Jim", "Sam", "Mary", 
                                     "Harry", "Sue", "Chris", "Joe", "Carl" };
        private string[] recDescs = { "Test", "Duplicate", "Standard", "Trial", "Expired", "New", "History" };
        private void CreateData()
        {
            Random r = new Random();
            Data = new ObservableCollection<GridData>();
            for (int i = 0; i < 10; i++)
            {
                GridData gd = new GridData()
                {
                    ID = i,
                    Name = names[r.Next(13)],
                    RecDesc = recDescs[r.Next(7)],
                    RecDate = DateTime.Today.AddDays(r.Next(10)),
                    Children = new ObservableCollection<GridData>()
                };
                AddChildren(gd, i);
                Data.Add(gd);
            }


        }
        private void AddChildren(GridData gd, int levelNo)
        {
            if (levelNo % 2 == 0)
                return;
            
            Random r = new Random();
            int NoChildren = r.Next(10);
            string levelStr = "1";
            for (int i = 0; i < levelNo; i++)
                levelStr += "0";


            int levelMult = int.Parse(levelStr);
            for (int i = 0; i < NoChildren; i++)
            {
                GridData gd2 = new GridData()
                {
                    ID = levelMult + i,
                    Name = names[r.Next(13)],
                    RecDesc = recDescs[r.Next(7)],
                    RecDate = DateTime.Today.AddDays(r.Next(10)),
                    Children = new ObservableCollection<GridData>()
                };

                if (levelNo < NoLevels)
                    AddChildren(gd2, levelNo + 1);

                gd.Children.Add(gd2);
            }
        }
    }
    public class GridData : INotifyPropertyChanged
    {

        private int id;
        private string name;
        private DateTime recDt;
        private string rec_desc;
        public ObservableCollection<GridData> Children { get; set; }


        public int ID
        {
            get { return id; }
            set
            {
                if (id != value)
                {
                    id = value;
                    OnPropertyChanged("ID");
                }
            }
        }

        public string Name
        {
            get { return name; }
            set
            {
                if (name != value)
                {
                    name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        public string RecDesc
        {
            get { return rec_desc; }
            set
            {
                if (rec_desc != value)
                {
                    rec_desc = value;
                    OnPropertyChanged("RecDesc");
                }
            }
        }

        public DateTime RecDate
        {
            get { return recDt; }
            set
            {
                if (recDt != value)
                {
                    recDt = value;
                    OnPropertyChanged("RecDate");
                }
            }
        }



        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}